;; Generated package description from gnu-elpa.el  -*- no-byte-compile: t -*-
(define-package "gnu-elpa" "1.1.0.20220703.125324" "Advertize GNU ELPA packages" '((emacs "25.1")) :commit "05eb02cc00edb42123c37baeee68e56d6a521997" :url "https://elpa.gnu.org/packages/gnu-elpa.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
